@@ -10,8 +10,9 @@ from checking.helpers.report import generate
 from .classes.listeners.basic import Listener
 from .classes.exc_thread import run_with_timeout
 from .classes.listeners.default import DefaultListener
-from .exceptions import UnknownProviderName, TestIgnoredException
 from checking.helpers.exception_traceback import exception_with_assert
+from .exceptions import UnknownProviderName, TestIgnoredException, OnlyIfFailedException, SkipTestException
+
 
 # Tests listener
 _listener: Listener
@@ -76,6 +77,9 @@ def start(verbose: int = 0, listener: Listener = None, groups: List[str] = None,
         common_parameters.update(params)
     if threads < 1:
         threads = 1
+    # if there is only one test group no need more than 1 thread!
+    if threads > 1 and len(test_suite.groups) <= 1:
+        threads = 1
     if dry_run:
         _dry_run(test_suite)
     # Check if all used provider names are found
@@ -194,8 +198,7 @@ def _run_test_with_provider(test):
                 list_of_arguments.append(param)
             is_one_of_before_test_failed = _run_test_with_before_and_after(clone, False)
             if is_one_of_before_test_failed:
-                print(f'Because of "before_test" all tests for {test} with data provider '
-                      f'"{test.provider}" was IGNORED!')
+                _listener.on_before_provider_failed(test, provider)
                 break
         # If no values at provider - ignore test
         if not is_any_value_provides:
@@ -206,7 +209,7 @@ def _run_test_with_provider(test):
                 test_suite.cache[provider] = tuple(list_of_arguments)
     except TypeError as e:
         if 'is not iterable' not in e.args[0]:
-            print(e)
+            _listener.on_error_with_provider(provider, e)
             raise
         else:
             test.stop(TestIgnoredException(f'Error with provider {test.provider}'))
@@ -256,7 +259,7 @@ def _provider_next(provider_name: str) -> Any:
     :param provider_name: name of the provider
     :return: generator
     """
-    iter_ = TestSuite.get_instance().providers[provider_name]()
+    iter_ = TestSuite.get_instance().providers[provider_name][0]()
     for param in iter_:
         yield param
     # If it were file at provider - try to close it
@@ -264,9 +267,8 @@ def _provider_next(provider_name: str) -> Any:
         try:
             iter_.close()
         except Exception as ex:
-            print(ex)
-            pass
-            # explicitly ignore
+            _listener.on_error_with_provider(provider_name, exc=ex)
+            # explicitly ignore, just notify our listener
 
 
 def _run_test(test: Test) -> bool:
@@ -295,7 +297,7 @@ def _run_test(test: Test) -> bool:
             global _can_run
             _can_run = False
             _listener.on_suite_stop_with_max_fail(_max_fail)
-    except (TestIgnoredException, SystemExit) as e:
+    except (TestIgnoredException, OnlyIfFailedException, SkipTestException, SystemExit) as e:
         test.stop(e)
         _listener.on_ignored_by_condition(test, e)
     except Exception as e:
